"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerProviders = void 0;
const factories_1 = require("../factories");
const services_1 = require("../services");
/**
 * Register all service providers
 */
function registerProviders() {
    registerAgileServiceProviders();
    registerRepoServiceProviders();
    registerLoggerServiceProviders();
}
exports.registerProviders = registerProviders;
/**
 * Register all Agile Service Providers
 */
function registerAgileServiceProviders() {
    factories_1.AgileServiceFactory.register(services_1.AgileServiceProvider.AzureDevOps, services_1.AzureDevOpsAgileService);
    factories_1.AgileServiceFactory.register(services_1.AgileServiceProvider.Jira, services_1.JiraAgileService);
    factories_1.AgileServiceFactory.register(services_1.AgileServiceProvider.GitHub, services_1.GitHubAgileService);
}
/**
 * Register all Repo Service Providers
 */
function registerRepoServiceProviders() {
    factories_1.RepoServiceFactory.register(services_1.RepoServiceProvider.GitHub, services_1.GitHubRepoService);
    factories_1.RepoServiceFactory.register(services_1.RepoServiceProvider.AzureDevOps, services_1.AzureDevOpsRepoService);
}
/**
 *
 */
function registerLoggerServiceProviders() {
    const consoleLogger = new services_1.ConsoleLogger();
    factories_1.LoggerFactory.register(services_1.LoggerProvider.Console, consoleLogger);
    factories_1.LoggerFactory.register(services_1.LoggerProvider.Composite, new services_1.CompositeLogger([consoleLogger]));
}
