/**
 * Properties to include with logs
 */
export interface LoggingProperties {
    [key: string]: string;
}
/**
 * Logger
 */
export interface Logger {
    /**
     * Log a message at debug severity level
     *
     * @param {string} message Message to log at debug severity level
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    debug: (message: string, properties?: LoggingProperties) => void;
    /**
     * Log a message at info severity level
     *
     * @param {string} message Message to log at info severity level
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    log: (message: string, properties?: LoggingProperties) => void;
    /**
     * Log a message at warn severity level
     *
     * @param {string} message Message to log at warn severity level
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    warn: (message: string, properties?: LoggingProperties) => void;
    /**
     * Log a message at error severity level
     *
     * @param {string} message Message to log at debug severity level
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    error: (message: string, properties?: LoggingProperties) => void;
    /**
     * Log a header message
     *
     * @param {string} message Header message
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    logHeader: (message: string, properties?: LoggingProperties) => void;
}
