import { Logger, LoggingProperties } from "../../models";
/**
 * Logger for multiple destinations
 */
export declare class CompositeLogger implements Logger {
    private loggers;
    constructor(loggers: Logger[]);
    /**
     * Log a message at debug severity level for all child loggers
     *
     * @param {string} message Message to log at debug severity level
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    debug(message: string, properties?: LoggingProperties): void;
    /**
     * Log a message at info severity level for all child loggers
     *
     * @param {string} message Message to log at info severity level
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    log(message: string, properties?: LoggingProperties): void;
    /**
     * Log a message at warn severity level for all child loggers
     *
     * @param {string} message Message to log at warn severity level
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    warn(message: string, properties?: LoggingProperties): void;
    /**
     * Log a message at error severity level for all child loggers
     *
     * @param {string} message Message to log at debug severity level
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    error(message: string, properties?: LoggingProperties): void;
    /**
     * Log a header message to all child loggers
     *
     * @param {string} message Header message
     * @param {LoggingProperties|undefined} properties Logging properties
     */
    logHeader(message: string, properties?: LoggingProperties): void;
}
